/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

var _baseGetTag = require('./dep-a9c0c920.js');
var isArray = require('./dep-161c0305.js');
var isObjectLike = require('./dep-b1b7627b.js');

/** `Object#toString` result references. */
var stringTag = '[object String]';

/**
 * Checks if `value` is classified as a `String` primitive or object.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a string, else `false`.
 * @example
 *
 * _.isString('abc');
 * // => true
 *
 * _.isString(1);
 * // => false
 */
function isString(value) {
  return typeof value == 'string' || !isArray.isArray(value) && isObjectLike.isObjectLike(value) && _baseGetTag.baseGetTag(value) == stringTag;
}

exports.isString = isString;
//# sourceMappingURL=dep-51f8b65c.js.map
