/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

/**
 * A specialized version of `_.map` for arrays without support for iteratee
 * shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the new mapped array.
 */
function arrayMap(array, iteratee) {
  var index = -1,
    length = array == null ? 0 : array.length,
    result = Array(length);
  while (++index < length) {
    result[index] = iteratee(array[index], index, array);
  }
  return result;
}

exports.arrayMap = arrayMap;
//# sourceMappingURL=dep-65b2a290.js.map
