/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var badge_index = require('../badge/index.js');
var image_index = require('../image/index.js');
var config = require('../config.js');
var avatar_props = require('./props.js');
var hooks_tnode = require('../hooks/tnode.js');
var hooks_useClass = require('../hooks/useClass.js');
var _common_js_avatar_utils = require('../_common/js/avatar/utils.js');
require('../badge/badge.js');
require('@babel/runtime/helpers/slicedToArray');
require('@babel/runtime/helpers/defineProperty');
require('../badge/props.js');
require('../_chunks/dep-51f8b65c.js');
require('../_chunks/dep-a9c0c920.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-161c0305.js');
require('../_chunks/dep-b1b7627b.js');
require('../_chunks/dep-619e29e1.js');
require('../shared/component.js');
require('../_chunks/dep-977081b1.js');
require('../_chunks/dep-90d1f1f6.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-5b94d99d.js');
require('../_chunks/dep-b912c957.js');
require('dayjs');
require('../_chunks/dep-107d4340.js');
require('../_chunks/dep-f8610152.js');
require('../_chunks/dep-95fd413d.js');
require('../_chunks/dep-b99dd3a6.js');
require('../_chunks/dep-9059ceab.js');
require('../_chunks/dep-48b1ccc0.js');
require('../_chunks/dep-7ede1657.js');
require('../_chunks/dep-11900ba0.js');
require('../_chunks/dep-68999828.js');
require('../_chunks/dep-8c8ba0a8.js');
require('../_chunks/dep-d8a9a6b3.js');
require('../_chunks/dep-4381ced7.js');
require('../_chunks/dep-533c057c.js');
require('../_chunks/dep-87690293.js');
require('../_chunks/dep-b55fb6e4.js');
require('../_chunks/dep-e11b336c.js');
require('../_chunks/dep-ec417fb3.js');
require('../hooks/render-tnode.js');
require('../_chunks/dep-cc4bd331.js');
require('../_chunks/dep-fb55187e.js');
require('../_chunks/dep-65b2a290.js');
require('../_chunks/dep-51b8dcc5.js');
require('../_chunks/dep-2c45a7c8.js');
require('../_chunks/dep-edb64bb3.js');
require('../_chunks/dep-216eb455.js');
require('../_chunks/dep-e1ee8baa.js');
require('../image/image.js');
require('@vueuse/core');
require('tdesign-icons-vue-next');
require('../loading/index.js');
require('../loading/loading.js');
require('../loading/icon/gradient.js');
require('../_common/js/loading/circle-adapter.js');
require('../_common/js/utils/setStyle.js');
require('../_common/js/utils/helper.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@babel/runtime/helpers/objectWithoutProperties');
require('../_chunks/dep-1f68b3d8.js');
require('../_chunks/dep-01f34845.js');
require('../loading/icon/spinner.js');
require('../loading/props.js');
require('../shared/dom.js');
require('../loading/plugin.js');
require('../image/props.js');

var prefix = config["default"].prefix;
var _Avatar = vue.defineComponent({
  name: "".concat(prefix, "-avatar"),
  props: avatar_props["default"],
  setup: function setup(props) {
    var renderTNodeJSX = hooks_tnode.useTNodeJSX();
    var renderTNodeContent = hooks_tnode.useContent();
    var avatarClass = hooks_useClass.usePrefixClass("avatar");
    var avatarGroupProps = vue.inject("avatarGroup", {});
    var hasAvatarGroupProps = Object.keys(avatarGroupProps).length > 0;
    var shapeValue = vue.computed(function () {
      return props.shape || (avatarGroupProps === null || avatarGroupProps === void 0 ? void 0 : avatarGroupProps.shape) || "circle";
    });
    var sizeValue = vue.computed(function () {
      return props.size || (avatarGroupProps === null || avatarGroupProps === void 0 ? void 0 : avatarGroupProps.size);
    });
    var isCustomSize = vue.computed(function () {
      return !_common_js_avatar_utils.isValidSize(sizeValue.value);
    });
    var avatarClasses = vue.computed(function () {
      return ["".concat(avatarClass.value), "".concat(avatarClass.value, "--").concat(isCustomSize.value ? "medium" : sizeValue.value), "".concat(avatarClass.value, "--").concat(shapeValue.value), hasAvatarGroupProps ? "".concat(avatarClass.value, "--border ").concat(avatarClass.value, "--border-").concat(isCustomSize.value ? "medium" : sizeValue.value) : ""];
    });
    var customSize = vue.computed(function () {
      return isCustomSize.value ? {
        height: sizeValue.value,
        width: sizeValue.value,
        "font-size": "".concat(Number.parseInt(sizeValue.value, 10) / 8 * 3 + 2, "px")
      } : {};
    });
    var handleImgLoadError = function handleImgLoadError(e) {
      var _props$onError;
      (_props$onError = props.onError) === null || _props$onError === void 0 || _props$onError.call(props, e);
    };
    return function () {
      var icon = renderTNodeJSX("icon");
      var TNodeContent = renderTNodeContent("default", "content");
      var readerAvatar = function readerAvatar() {
        if (props.image && !props.hideOnLoadFailed) {
          return vue.createVNode(image_index.Image, vue.mergeProps({
            "src": props.image,
            "alt": props.alt
          }, props.imageProps, {
            "onError": handleImgLoadError
          }), null);
        }
        if (icon) {
          return vue.createVNode("div", {
            "class": "".concat(avatarClass.value, "__icon")
          }, [icon]);
        }
        return vue.createVNode(vue.Fragment, null, [TNodeContent]);
      };
      return vue.createVNode("div", {
        "class": "".concat(avatarClass.value, "__wrapper")
      }, [vue.createVNode("div", {
        "class": "".concat(avatarClass.value, "__badge")
      }, [vue.createVNode(badge_index.Badge, props.badgeProps, {
        default: function _default() {
          return [vue.createVNode("div", {
            "class": avatarClasses.value,
            "style": customSize.value
          }, [readerAvatar()])];
        }
      })])]);
    };
  }
});

exports["default"] = _Avatar;
//# sourceMappingURL=avatar.js.map
