/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var vue = require('vue');
var config = require('../config.js');
var picker_picker_class = require('./picker.class.js');
var hooks_useClass = require('../hooks/useClass.js');
var get = require('../_chunks/dep-99f0ef00.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@babel/runtime/helpers/classCallCheck');
require('@babel/runtime/helpers/createClass');
require('../shared/dom.js');
require('../_chunks/dep-9059ceab.js');
require('../_chunks/dep-a9c0c920.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-48b1ccc0.js');
require('../_chunks/dep-51f8b65c.js');
require('../_chunks/dep-161c0305.js');
require('../_chunks/dep-b1b7627b.js');
require('./utils.js');
require('../_chunks/dep-977081b1.js');
require('../_chunks/dep-90d1f1f6.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-5b94d99d.js');
require('../_chunks/dep-b912c957.js');
require('dayjs');
require('../_chunks/dep-107d4340.js');
require('../_chunks/dep-f8610152.js');
require('../_chunks/dep-95fd413d.js');
require('../_chunks/dep-b99dd3a6.js');
require('../_chunks/dep-7ede1657.js');
require('../_chunks/dep-11900ba0.js');
require('../_chunks/dep-68999828.js');
require('../_chunks/dep-8c8ba0a8.js');
require('../_chunks/dep-d8a9a6b3.js');
require('../_chunks/dep-4381ced7.js');
require('../_chunks/dep-533c057c.js');
require('../_chunks/dep-87690293.js');
require('../_chunks/dep-b55fb6e4.js');
require('../_chunks/dep-e11b336c.js');
require('../_chunks/dep-ec417fb3.js');
require('../_chunks/dep-160a3aa4.js');
require('../_chunks/dep-51b8dcc5.js');
require('../_chunks/dep-fb55187e.js');
require('../_chunks/dep-65b2a290.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);

var prefix = config["default"].prefix;
var PickerItem = vue.defineComponent({
  name: "".concat(prefix, "-picker-item"),
  props: {
    options: {
      type: Array
    },
    value: {
      type: [String, Number],
      default: void 0
    },
    renderLabel: {
      type: Function,
      default: void 0
    },
    onPick: {
      type: Function,
      default: void 0
    },
    swipeDuration: {
      type: [String, Number],
      default: 300
    }
  },
  emits: ["pick"],
  setup: function setup(props, context) {
    var pickerItemClass = hooks_useClass.usePrefixClass("picker-item");
    var pickerProps = vue.inject("picker", void 0);
    var keys = vue.computed(function () {
      var _pickerProps$keys;
      return pickerProps && ((_pickerProps$keys = pickerProps.keys) === null || _pickerProps$keys === void 0 ? void 0 : _pickerProps$keys.value);
    });
    var picker = null;
    var root = vue.ref();
    var getIndexByValue = function getIndexByValue(val) {
      var defaultIndex = 0;
      if (val !== void 0) {
        var _props$options;
        defaultIndex = (_props$options = props.options) === null || _props$options === void 0 ? void 0 : _props$options.findIndex(function (item) {
          var _keys$value$value, _keys$value;
          return get.get(item, (_keys$value$value = (_keys$value = keys.value) === null || _keys$value === void 0 ? void 0 : _keys$value.value) !== null && _keys$value$value !== void 0 ? _keys$value$value : "value") === val;
        });
      }
      return defaultIndex < 0 ? 0 : defaultIndex;
    };
    var className = vue.computed(function () {
      return "".concat(pickerItemClass.value);
    });
    var updatePickerWithNextTick = function updatePickerWithNextTick(index) {
      if (picker) {
        picker.updateItems();
        vue.nextTick(function () {
          picker.updateIndex(index, {
            isChange: false
          });
        });
      }
    };
    var setIndex = function setIndex(index) {
      updatePickerWithNextTick(index);
    };
    var setValue = function setValue(value) {
      var index = getIndexByValue(value);
      updatePickerWithNextTick(index);
    };
    var setOptions = function setOptions() {
      var _picker;
      (_picker = picker) === null || _picker === void 0 || _picker.update();
    };
    var setUpdateItems = function setUpdateItems() {
      var _picker2;
      (_picker2 = picker) === null || _picker2 === void 0 || _picker2.updateItems();
    };
    context.expose({
      setIndex: setIndex,
      setValue: setValue,
      setOptions: setOptions,
      setUpdateItems: setUpdateItems
    });
    vue.onMounted(function () {
      if (root.value) {
        picker = new picker_picker_class["default"]({
          el: root.value,
          defaultIndex: getIndexByValue(props.value) || 0,
          keys: keys.value,
          defaultPickerColumns: props.options,
          onChange: function onChange(index) {
            var _keys$value$value2, _keys$value2, _props$onPick;
            var curItem = props.options[index];
            var changeValue = {
              value: get.get(curItem, (_keys$value$value2 = (_keys$value2 = keys.value) === null || _keys$value2 === void 0 ? void 0 : _keys$value2.value) !== null && _keys$value$value2 !== void 0 ? _keys$value$value2 : "value"),
              index: index
            };
            (_props$onPick = props.onPick) === null || _props$onPick === void 0 || _props$onPick.call(props, changeValue);
          },
          swipeDuration: props.swipeDuration
        });
      }
    });
    vue.watch(function () {
      return props.options;
    }, function () {
      var _picker3, _picker4;
      (_picker3 = picker) === null || _picker3 === void 0 || _picker3.updateOptions(props.options);
      (_picker4 = picker) === null || _picker4 === void 0 || _picker4.updateItems();
    }, {
      flush: "post",
      deep: true
    });
    return function () {
      return vue.createVNode("ul", {
        "ref": root,
        "class": className.value
      }, [(props.options || []).map(function (option, index) {
        var _keys$value$disabled, _keys$value3, _keys$value$label, _keys$value4;
        return vue.createVNode("li", {
          "key": index,
          "class": ["".concat(pickerItemClass.value, "__item"), _defineProperty__default["default"]({}, "".concat(pickerItemClass.value, "__item--disabled"), get.get(option, (_keys$value$disabled = (_keys$value3 = keys.value) === null || _keys$value3 === void 0 ? void 0 : _keys$value3.disabled) !== null && _keys$value$disabled !== void 0 ? _keys$value$disabled : "disabled"))]
        }, [context.slots.option ? context.slots.option(option, index) : vue.createVNode(vue.Fragment, null, [props.renderLabel ? props.renderLabel(option) : get.get(option, (_keys$value$label = (_keys$value4 = keys.value) === null || _keys$value4 === void 0 ? void 0 : _keys$value4.label) !== null && _keys$value$label !== void 0 ? _keys$value$label : "label")])]);
      })]);
    };
  }
});

exports["default"] = PickerItem;
//# sourceMappingURL=picker-item.js.map
