/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var tdesignIconsVueNext = require('tdesign-icons-vue-next');
var image_index = require('../image/index.js');
var imageViewer_index = require('../image-viewer/index.js');
var upload_props = require('./props.js');
var config = require('../config.js');
var upload_hooks_useUpload = require('./hooks/useUpload.js');
var hooks_tnode = require('../hooks/tnode.js');
var hooks_useClass = require('../hooks/useClass.js');
var configProvider_useConfig = require('../_chunks/dep-977081b1.js');
require('../image/image.js');
require('@babel/runtime/helpers/slicedToArray');
require('@babel/runtime/helpers/defineProperty');
require('@vueuse/core');
require('../loading/index.js');
require('../loading/loading.js');
require('../loading/icon/gradient.js');
require('../_common/js/loading/circle-adapter.js');
require('../_common/js/utils/setStyle.js');
require('../_common/js/utils/helper.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@babel/runtime/helpers/objectWithoutProperties');
require('../_chunks/dep-1f68b3d8.js');
require('../_chunks/dep-01f34845.js');
require('../_chunks/dep-51f8b65c.js');
require('../_chunks/dep-a9c0c920.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-161c0305.js');
require('../_chunks/dep-b1b7627b.js');
require('../_chunks/dep-619e29e1.js');
require('../loading/icon/spinner.js');
require('../loading/props.js');
require('../shared/dom.js');
require('../_chunks/dep-9059ceab.js');
require('../_chunks/dep-48b1ccc0.js');
require('../loading/plugin.js');
require('../_chunks/dep-90d1f1f6.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-5b94d99d.js');
require('../_chunks/dep-b912c957.js');
require('dayjs');
require('../_chunks/dep-107d4340.js');
require('../_chunks/dep-f8610152.js');
require('../_chunks/dep-95fd413d.js');
require('../_chunks/dep-b99dd3a6.js');
require('../_chunks/dep-7ede1657.js');
require('../_chunks/dep-11900ba0.js');
require('../_chunks/dep-68999828.js');
require('../_chunks/dep-8c8ba0a8.js');
require('../_chunks/dep-d8a9a6b3.js');
require('../_chunks/dep-4381ced7.js');
require('../_chunks/dep-533c057c.js');
require('../_chunks/dep-87690293.js');
require('../_chunks/dep-b55fb6e4.js');
require('../hooks/render-tnode.js');
require('../_chunks/dep-cc4bd331.js');
require('../_chunks/dep-fb55187e.js');
require('../_chunks/dep-65b2a290.js');
require('../_chunks/dep-51b8dcc5.js');
require('../_chunks/dep-2c45a7c8.js');
require('../_chunks/dep-edb64bb3.js');
require('../_chunks/dep-216eb455.js');
require('../_chunks/dep-e1ee8baa.js');
require('../_chunks/dep-ec417fb3.js');
require('../_chunks/dep-e11b336c.js');
require('../shared/component.js');
require('../image/props.js');
require('../image-viewer/image-viewer.js');
require('../image-viewer/props.js');
require('../hooks/useDefaultValue.js');
require('../hooks/useVModel.js');
require('../swiper/index.js');
require('../swiper/swiper.js');
require('../swipe-cell/useSwipe.js');
require('../shared/util.js');
require('../swiper/props.js');
require('../swiper/swiper-item.js');
require('../shared/useGesture/index.js');
require('@use-gesture/vanilla');
require('../_common/js/upload/main.js');
require('@babel/runtime/helpers/toArray');
require('../_common/js/upload/utils.js');
require('../_common/js/log/log.js');
require('../_common/js/upload/xhr.js');

var prefix = config["default"].prefix;
var _Upload = vue.defineComponent({
  name: "".concat(prefix, "-upload"),
  components: {
    TImage: image_index.Image
  },
  props: upload_props["default"],
  emits: ["update:files", "update:modelValue", "change", "fail", "preview", "progress", "remove", "success", "select-change", "validate", "click-upload"],
  setup: function setup(props, _ref) {
    var expose = _ref.expose;
    var uploadClass = hooks_useClass.usePrefixClass("upload");
    var _useConfig = configProvider_useConfig.useConfig("upload"),
      globalConfig = _useConfig.globalConfig;
    var _useUpload = upload_hooks_useUpload["default"](props),
      disabled = _useUpload.disabled,
      displayFiles = _useUpload.displayFiles,
      uploading = _useUpload.uploading,
      inputRef = _useUpload.inputRef,
      uploadFilePercent = _useUpload.uploadFilePercent,
      uploadFiles = _useUpload.uploadFiles,
      onNormalFileChange = _useUpload.onNormalFileChange,
      onInnerRemove = _useUpload.onInnerRemove,
      cancelUpload = _useUpload.cancelUpload;
    var renderTNodeJSX = hooks_tnode.useTNodeJSX();
    var renderContent = hooks_tnode.useContent();
    var showViewer = vue.ref(false);
    var initialIndex = vue.ref(0);
    var handlePreview = function handlePreview(e, file, index) {
      var _props$onPreview;
      initialIndex.value = index;
      showViewer.value = props.preview;
      (_props$onPreview = props.onPreview) === null || _props$onPreview === void 0 || _props$onPreview.call(props, {
        e: e,
        file: file,
        index: index
      });
    };
    var triggerUpload = function triggerUpload(e) {
      var _props$onClickUpload;
      var input = inputRef.value;
      if (disabled !== null && disabled !== void 0 && disabled.value) return;
      input.click();
      (_props$onClickUpload = props.onClickUpload) === null || _props$onClickUpload === void 0 || _props$onClickUpload.call(props, {
        e: e
      });
    };
    var previewImgs = vue.computed(function () {
      return displayFiles.value.map(function (item) {
        return item.url;
      });
    });
    var handleImageClose = function handleImageClose(_ref2) {
      var visible = _ref2.visible;
      showViewer.value = visible;
    };
    var renderStatus = function renderStatus(file) {
      if (file.status === "fail" || file.status === "progress") {
        return vue.createVNode("div", {
          "class": "".concat(uploadClass.value, "__progress-mask")
        }, [file.status === "progress" ? vue.createVNode(vue.Fragment, null, [vue.createVNode(tdesignIconsVueNext.LoadingIcon, {
          "class": "".concat(uploadClass.value, "__progress-loading"),
          "size": "24"
        }, null), vue.createVNode("div", {
          "class": "".concat(uploadClass.value, "__progress-text")
        }, [file.percent ? "".concat(file.percent, "%") : globalConfig.value.progress.uploadingText])]) : vue.createVNode(tdesignIconsVueNext.CloseCircleIcon, {
          "size": "24"
        }, null), file.status === "fail" && vue.createVNode("div", {
          "class": "".concat(uploadClass.value, "__progress-text")
        }, [globalConfig.value.progress.failText])]);
      }
    };
    var content = function content() {
      var _displayFiles$value;
      var defaultContent = renderContent("default", "content");
      var addContent = renderTNodeJSX("addContent");
      if (props.max === 0 || props.max > 0 && ((_displayFiles$value = displayFiles.value) === null || _displayFiles$value === void 0 ? void 0 : _displayFiles$value.length) < props.max) {
        if (defaultContent) {
          return vue.createVNode("div", {
            "onClick": triggerUpload
          }, [defaultContent]);
        }
        return vue.createVNode("div", {
          "class": "".concat(uploadClass.value, "__item ").concat(uploadClass.value, "__item--add"),
          "onClick": triggerUpload
        }, [vue.createVNode("div", {
          "class": "".concat(uploadClass.value, "__add-icon")
        }, [addContent || vue.createVNode(tdesignIconsVueNext.AddIcon, {
          "size": "28"
        }, null)])]);
      }
    };
    expose({
      upload: inputRef.value,
      uploading: uploading,
      triggerUpload: triggerUpload,
      uploadFiles: uploadFiles,
      cancelUpload: cancelUpload,
      uploadFilePercent: uploadFilePercent
    });
    return function () {
      return vue.createVNode("div", {
        "class": "".concat(uploadClass.value)
      }, [displayFiles.value.map(function (file, index) {
        return vue.createVNode("div", {
          "key": index,
          "class": "".concat(uploadClass.value, "__item")
        }, [file.url && vue.createVNode(vue.resolveComponent("t-image"), vue.mergeProps({
          "class": "".concat(uploadClass.value, "__image"),
          "shape": "round"
        }, props.imageProps, {
          "src": file.url,
          "onClick": function onClick(e) {
            return handlePreview(e, file, index);
          }
        }), null), renderStatus(file), vue.createVNode(tdesignIconsVueNext.CloseIcon, {
          "class": "".concat(uploadClass.value, "__delete-btn"),
          "onClick": function onClick(_ref3) {
            var e = _ref3.e;
            return onInnerRemove({
              e: e,
              file: file,
              index: index
            });
          }
        }, null)]);
      }), content(), vue.createVNode("input", {
        "ref": inputRef,
        "value": props.files,
        "type": "file",
        "multiple": props.multiple,
        "hidden": true,
        "capture": props.capture,
        "accept": props.accept,
        "onChange": onNormalFileChange
      }, null), vue.createVNode(imageViewer_index.ImageViewer, {
        "visible": showViewer.value,
        "images": previewImgs.value,
        "index": initialIndex.value,
        "onClose": handleImageClose
      }, null)]);
    };
  }
});

exports["default"] = _Upload;
//# sourceMappingURL=upload.js.map
