/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { _ as _defineProperty } from '../_chunks/dep-2822c770.mjs';
import { isVNode, defineComponent, inject, computed, createVNode, resolveComponent, mergeProps, withDirectives, resolveDirective } from 'vue';
import { isString, isObject, isFunction } from 'lodash-es';
import '../shared/index.mjs';
import config from '../config.mjs';
import props from './grid-item-props.mjs';
import { useTNodeJSX } from '../hooks/tnode.mjs';
import { Image } from '../image/index.mjs';
import { Badge } from '../badge/index.mjs';
import { usePrefixClass } from '../hooks/useClass.mjs';
import Hover from '../shared/hover.mjs';
import '../_chunks/dep-0f7e0eb1.mjs';
import '../shared/functions.mjs';
import '../shared/util.mjs';
import '../_chunks/dep-0a95ce1b.mjs';
import '../_chunks/dep-3a5e8269.mjs';
import '../shared/component.mjs';
import '../shared/constants.mjs';
import '../shared/render.mjs';
import '../shared/dom.mjs';
import '../shared/render-tnode.mjs';
import '../shared/useToggle/index.mjs';
import '../shared/useCountDown/index.mjs';
import '../_chunks/dep-ebc76206.mjs';
import '../_chunks/dep-308d506d.mjs';
import '@vueuse/core';
import '../shared/useCountDown/utils.mjs';
import '../shared/useChildSlots/index.mjs';
import '../_chunks/dep-af443fd2.mjs';
import '../shared/useTouch/index.mjs';
import '../shared/useScrollParent/index.mjs';
import '../shared/useExpose/index.mjs';
import '../shared/useTest/index.mjs';
import '../shared/useClickAway/index.mjs';
import '../shared/useGesture/index.mjs';
import '@use-gesture/vanilla';
import '../hooks/render-tnode.mjs';
import '../image/image.mjs';
import 'tdesign-icons-vue-next';
import '../loading/index.mjs';
import '../loading/loading.mjs';
import '../loading/icon/gradient.mjs';
import '../_common/js/loading/circle-adapter.mjs';
import '../_common/js/utils/setStyle.mjs';
import '../_common/js/utils/helper.mjs';
import '../_chunks/dep-f875d251.mjs';
import '../loading/icon/spinner.mjs';
import '../loading/props.mjs';
import './style/css.mjs';
import '../loading/type.mjs';
import '../loading/plugin.mjs';
import '../config-provider/useConfig.mjs';
import '../config-provider/context.mjs';
import '../_common/js/global-config/mobile/default-config.mjs';
import '../_common/js/global-config/mobile/locale/zh_CN.mjs';
import '../_chunks/dep-2a1ce6fa.mjs';
import '../_chunks/dep-057983c9.mjs';
import '../_chunks/dep-735bd654.mjs';
import '../config-provider/type.mjs';
import '../image/props.mjs';
import '../image/type.mjs';
import '../badge/badge.mjs';
import '../badge/props.mjs';
import '../badge/type.mjs';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !isVNode(s);
}
var prefix = config.prefix;
var _GridItem = defineComponent({
  name: "".concat(prefix, "-grid-item"),
  directives: {
    Hover: Hover
  },
  components: {
    TImage: Image,
    TBadge: Badge
  },
  props: props,
  setup: function setup(props2, context) {
    var gridItemClass = usePrefixClass("grid-item");
    var renderTNodeJSX = useTNodeJSX();
    var _inject = inject("grid"),
      column = _inject.column,
      border = _inject.border,
      align = _inject.align,
      gutter = _inject.gutter,
      hover = _inject.hover;
    var rootStyle = computed(function () {
      var percent = column.value > 0 ? "".concat(100 / +column.value, "%") : 0;
      var style = {
        textAlign: ["center", "left"].includes(align.value) ? align.value : "center"
      };
      if (percent !== 0) {
        style.flexBasis = percent;
      }
      return style;
    });
    var size = computed(function () {
      if (column.value > 4 || !column.value) return "small";
      return column.value < 4 ? "large" : "middle";
    });
    var realImage = computed(function () {
      if (isString(props2.image)) return {
        src: props2.image
      };
      if (isObject(props2.image) && !isFunction(props2.image) && !context.slots.image) {
        return props2.image;
      }
      return null;
    });
    var gridItemClasses = computed(function () {
      return ["".concat(gridItemClass.value), "".concat(gridItemClass.value, "--").concat(props2.layout), _defineProperty(_defineProperty({}, "".concat(gridItemClass.value, "--bordered"), border.value), "".concat(gridItemClass.value, "--surround"), border.value && gutter.value)];
    });
    return function () {
      var _slot;
      var renderImage = function renderImage() {
        if (realImage.value) {
          return createVNode(resolveComponent("t-image"), mergeProps({
            "shape": "round"
          }, realImage.value), null);
        }
        if (props2.icon) {
          return renderTNodeJSX("icon");
        }
        return renderTNodeJSX("image");
      };
      return withDirectives(createVNode("div", {
        "class": gridItemClasses.value,
        "style": rootStyle.value
      }, [createVNode("div", {
        "class": "".concat(gridItemClass.value, "__image ").concat(gridItemClass.value, "__image--").concat(size.value)
      }, [props2.badge ? createVNode(resolveComponent("t-badge"), props2.badge, _isSlot(_slot = renderImage()) ? _slot : {
        default: function _default() {
          return [_slot];
        }
      }) : renderImage()]), createVNode("div", {
        "class": "".concat(gridItemClass.value, "__content ").concat(gridItemClass.value, "__content--").concat(props2.layout)
      }, [createVNode("div", {
        "class": "".concat(gridItemClass.value, "__title ").concat(gridItemClass.value, "__title--").concat(size.value)
      }, [renderTNodeJSX("text")]), createVNode("div", {
        "class": "".concat(gridItemClass.value, "__description ").concat(gridItemClass.value, "__description--").concat(props2.layout)
      }, [renderTNodeJSX("description")])])]), [[resolveDirective("hover"), {
        className: "".concat(gridItemClass.value, "--hover"),
        disabledHover: !hover.value
      }]]);
    };
  }
});

export { _GridItem as default };
//# sourceMappingURL=grid-item.mjs.map
