/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { _ as _defineProperty } from '../_chunks/dep-2822c770.mjs';
import { _ as _slicedToArray } from '../_chunks/dep-0a95ce1b.mjs';
import { defineComponent, toRefs, computed, createVNode, h } from 'vue';
import { isArray, isString, isFunction } from 'lodash-es';
import { Loading } from '../loading/index.mjs';
import '../shared/index.mjs';
import config from '../config.mjs';
import props from './props.mjs';
import { useFormDisabled } from '../form/hooks.mjs';
import useVModel from '../hooks/useVModel.mjs';
import { usePrefixClass } from '../hooks/useClass.mjs';
import { useToggle } from '../shared/useToggle/index.mjs';
import '../_chunks/dep-0f7e0eb1.mjs';
import '../_chunks/dep-3a5e8269.mjs';
import '../loading/loading.mjs';
import '../loading/icon/gradient.mjs';
import '../_common/js/loading/circle-adapter.mjs';
import '../_common/js/utils/setStyle.mjs';
import '../_common/js/utils/helper.mjs';
import '../_chunks/dep-af443fd2.mjs';
import '../_chunks/dep-f875d251.mjs';
import '../loading/icon/spinner.mjs';
import '../loading/props.mjs';
import '../hooks/tnode.mjs';
import '../hooks/render-tnode.mjs';
import '../shared/dom.mjs';
import './style/css.mjs';
import '../loading/type.mjs';
import '../loading/plugin.mjs';
import '../config-provider/useConfig.mjs';
import '../config-provider/context.mjs';
import '../_common/js/global-config/mobile/default-config.mjs';
import '../_common/js/global-config/mobile/locale/zh_CN.mjs';
import '../_chunks/dep-2a1ce6fa.mjs';
import '../_chunks/dep-308d506d.mjs';
import '../_chunks/dep-057983c9.mjs';
import '../_chunks/dep-735bd654.mjs';
import '../config-provider/type.mjs';
import '../shared/component.mjs';
import '../shared/functions.mjs';
import '../shared/util.mjs';
import '../shared/constants.mjs';
import '../shared/render.mjs';
import '../shared/render-tnode.mjs';
import '../shared/useCountDown/index.mjs';
import '../_chunks/dep-ebc76206.mjs';
import '@vueuse/core';
import '../shared/useCountDown/utils.mjs';
import '../shared/useChildSlots/index.mjs';
import '../shared/useTouch/index.mjs';
import '../shared/useScrollParent/index.mjs';
import '../shared/useExpose/index.mjs';
import '../shared/useTest/index.mjs';
import '../shared/useClickAway/index.mjs';
import '../shared/useGesture/index.mjs';
import '@use-gesture/vanilla';
import '../shared/hover.mjs';

var prefix = config.prefix;
var _Switch = defineComponent({
  name: "".concat(prefix, "-switch"),
  props: props,
  setup: function setup(props2, context) {
    var switchClass = usePrefixClass("switch");
    var disabled = useFormDisabled();
    var switchValues = props2.customValue || [true, false];
    var _toRefs = toRefs(props2),
      value = _toRefs.value,
      modelValue = _toRefs.modelValue;
    var _useVModel = useVModel(value, modelValue, props2.defaultValue, props2.onChange),
      _useVModel2 = _slicedToArray(_useVModel, 2),
      innerValue = _useVModel2[0],
      setInnerValue = _useVModel2[1];
    var _useToggle = useToggle(switchValues, innerValue.value),
      state = _useToggle.state,
      toggle = _useToggle.toggle;
    var checked = computed(function () {
      return innerValue.value === switchValues[0];
    });
    var switchClasses = computed(function () {
      return ["".concat(switchClass.value), "".concat(switchClass.value, "--").concat(props2.size), _defineProperty(_defineProperty({}, "".concat(switchClass.value, "--checked"), checked.value), "".concat(switchClass.value, "--disabled"), disabled.value || props2.loading)];
    });
    var dotClasses = computed(function () {
      var _props2$label, _props2$icon;
      return ["".concat(switchClass.value, "__dot"), "".concat(switchClass.value, "__dot--").concat(props2.size), _defineProperty(_defineProperty({}, "".concat(switchClass.value, "__dot--checked"), checked.value), "".concat(switchClass.value, "__dot--plain"), ((_props2$label = props2.label) === null || _props2$label === void 0 ? void 0 : _props2$label.length) !== 2 && ((_props2$icon = props2.icon) === null || _props2$icon === void 0 ? void 0 : _props2$icon.length) !== 2 && !props2.loading)];
    });
    var labelClasses = computed(function () {
      return ["".concat(switchClass.value, "__label"), "".concat(switchClass.value, "__label--").concat(props2.size), _defineProperty({}, "".concat(switchClass.value, "__label--checked"), checked.value)];
    });
    var iconContent = computed(function () {
      return props2.icon[checked.value ? 0 : 1];
    });
    function handleToggle(event) {
      event.preventDefault();
      if (disabled.value || props2.loading) {
        return;
      }
      if (state.value === innerValue.value) {
        toggle();
      }
      setInnerValue(state.value);
    }
    var renderContent = function renderContent() {
      if (props2.loading) {
        return createVNode(Loading, {
          "inherit-color": true,
          "size": "16.25px"
        }, null);
      }
      if (isArray(props2.label) && props2.label.length === 2) {
        var label = checked.value ? props2.label[0] : props2.label[1];
        if (isString(label)) {
          return label;
        }
        if (isFunction(label)) {
          return label(h);
        }
      }
      if (isFunction(props2.label)) {
        return props2.label(h, {
          value: innerValue.value
        });
      }
      if (context.slots.label) {
        return context.slots.label({
          value: innerValue.value
        });
      }
      return iconContent.value;
    };
    return function () {
      return createVNode("div", {
        "class": switchClasses.value,
        "onClick": handleToggle
      }, [createVNode("div", {
        "class": dotClasses.value
      }, [createVNode("div", {
        "class": labelClasses.value
      }, [renderContent()])])]);
    };
  }
});

export { _Switch as default };
//# sourceMappingURL=switch.mjs.map
