/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import { isVNode, defineComponent, reactive, toRefs, computed, ref, h, nextTick, watch, onUnmounted, createVNode, Transition } from 'vue';
import { CloseIcon, DeleteIcon } from 'tdesign-icons-vue-next';
import config from '../config.js';
import props from './props.js';
import useDefaultValue from '../hooks/useDefaultValue.js';
import '../shared/index.js';
import useVModel from '../hooks/useVModel.js';
import { useTNodeJSX } from '../hooks/tnode.js';
import { usePrefixClass } from '../hooks/useClass.js';
import { Swiper, SwiperItem } from '../swiper/index.js';
import { isBrowser } from '../shared/util.js';
import { useGesture } from '../shared/useGesture/index.js';
import 'lodash-es';
import '../shared/functions.js';
import '../shared/component.js';
import '../shared/constants.js';
import '../shared/render.js';
import '@babel/runtime/helpers/typeof';
import '../shared/dom.js';
import '../shared/render-tnode.js';
import '../shared/useToggle/index.js';
import '../shared/useCountDown/index.js';
import '@babel/runtime/helpers/asyncToGenerator';
import '@babel/runtime/regenerator';
import '@vueuse/core';
import '../shared/useCountDown/utils.js';
import '../shared/useChildSlots/index.js';
import '@babel/runtime/helpers/toConsumableArray';
import '../shared/useTouch/index.js';
import '../shared/useScrollParent/index.js';
import '../shared/useExpose/index.js';
import '../shared/useTest/index.js';
import '@babel/runtime/helpers/defineProperty';
import '../shared/useClickAway/index.js';
import '../shared/hover.js';
import '@use-gesture/vanilla';
import '../hooks/render-tnode.js';
import '../config-provider/useConfig.js';
import '../config-provider/context.js';
import '../_common/js/global-config/mobile/default-config.js';
import '../_common/js/global-config/mobile/locale/zh_CN.js';
import '../_chunks/dep-1f914f51.js';
import '../_chunks/dep-10ba61db.js';
import 'dayjs';
import '../_chunks/dep-5b3ad5d0.js';
import '../config-provider/type.js';
import '../swiper/swiper.js';
import '../swipe-cell/useSwipe.js';
import '../swiper/props.js';
import '../swiper/swiper-item.js';
import '../swiper/style';
import '../swiper/type.js';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !isVNode(s);
}
var prefix = config.prefix;
var TAP_TIME = 300;
var _ImageViewer = defineComponent({
  name: "".concat(prefix, "-image-viewer"),
  props: props,
  emits: ["close", "index-change", "update:visible", "update:modelValue", "update:index", "delete"],
  setup: function setup(props2, _ref) {
    var _props2$defaultIndex;
    var emit = _ref.emit;
    var imageViewerClass = usePrefixClass("image-viewer");
    var state = reactive({
      dblTapZooming: false,
      zooming: false,
      scale: 1,
      touchIndex: 0,
      dragging: false,
      draggedX: 0,
      draggedY: 0,
      extraDraggedX: 0
    });
    var _toRefs = toRefs(props2),
      index = _toRefs.index,
      visible = _toRefs.visible,
      modelValue = _toRefs.modelValue;
    var _useVModel = useVModel(visible, modelValue, props2.defaultVisible, function () {}, "visible"),
      _useVModel2 = _slicedToArray(_useVModel, 2),
      visibleValue = _useVModel2[0],
      setVisibleValue = _useVModel2[1];
    var _useDefaultValue = useDefaultValue(index, (_props2$defaultIndex = props2.defaultIndex) !== null && _props2$defaultIndex !== void 0 ? _props2$defaultIndex : 0, props2.onIndexChange, "index"),
      _useDefaultValue2 = _slicedToArray(_useDefaultValue, 2),
      currentIndex = _useDefaultValue2[0],
      setCurrentIndex = _useDefaultValue2[1];
    var preloadImageIndex = computed(function () {
      var lastIndex = props2.images.length - 1;
      if ([void 0, 0].includes(currentIndex.value)) {
        return [0, 1, lastIndex];
      }
      if (currentIndex.value === lastIndex) {
        return [lastIndex, lastIndex - 1, 0];
      }
      var prev = currentIndex.value - 1 >= 0 ? currentIndex.value - 1 : lastIndex;
      var next = currentIndex.value + 1 <= lastIndex ? currentIndex.value + 1 : 0;
      return [currentIndex.value, prev, next];
    });
    var imageInfoList = computed(function () {
      return props2.images.map(function (image, index2) {
        var imageInfo;
        if (typeof image === "string") {
          imageInfo = {
            url: image,
            align: "center"
          };
        } else {
          imageInfo = image;
        }
        return {
          image: imageInfo,
          preload: preloadImageIndex.value.includes(index2)
        };
      });
    });
    var disabled = ref(false);
    var rootRef = ref();
    var imagesSize = reactive({});
    var swiperRootRef = ref();
    var swiperItemRefs = ref([]);
    var gestureRef = ref();
    var renderTNodeJSX = useTNodeJSX();
    var closeNode = computed(function () {
      return renderTNodeJSX("closeBtn", h(CloseIcon));
    });
    var deleteNode = computed(function () {
      return renderTNodeJSX("deleteBtn", h(DeleteIcon));
    });
    var imageTransform = computed(function () {
      var scale = state.scale,
        draggedX = state.draggedX,
        draggedY = state.draggedY;
      return "matrix(".concat(scale, ", 0, 0, ").concat(scale, ", ").concat(draggedX, ", ").concat(draggedY, ")");
    });
    var imageTransitionDuration = computed(function () {
      var zooming = state.zooming,
        dragging = state.dragging;
      return zooming || dragging ? "transition-duration: 0s" : "transition-duration: 0.3s";
    });
    var beforeClose = function beforeClose() {
      state.dblTapZooming = false;
      state.zooming = false;
      state.scale = 1;
      state.dragging = false;
      state.draggedX = 0;
      state.draggedY = 0;
      state.extraDraggedX = 0;
    };
    var handleClose = function handleClose(e, trigger) {
      beforeClose();
      setVisibleValue(false);
      emit("close", {
        trigger: trigger,
        e: e
      });
    };
    var handleDelete = function handleDelete() {
      var _currentIndex$value;
      emit("delete", (_currentIndex$value = currentIndex.value) !== null && _currentIndex$value !== void 0 ? _currentIndex$value : 0);
    };
    var setImagePreload = function setImagePreload(index2) {
      var nextIndex = index2 >= imageInfoList.value.length - 1 ? 0 : index2 + 1;
      var preIndex = index2 <= 0 ? imageInfoList.value.length - 1 : index2 - 1;
      imageInfoList.value[preIndex].preload = true;
      imageInfoList.value[nextIndex].preload = true;
    };
    var onSwiperChange = function onSwiperChange(index2, context) {
      if (currentIndex.value !== index2) {
        var trigger = currentIndex.value < index2 ? "next" : "prev";
        setCurrentIndex(index2, {
          trigger: trigger
        });
        setScale(1);
        setImagePreload(index2);
      }
    };
    var onImgLoad = function onImgLoad(e, index2) {
      var height = e.target.height;
      imagesSize[index2] = {
        height: height
      };
    };
    var getMaxDraggedX = function getMaxDraggedX() {
      var _rootRef$value;
      var rootOffsetWidth = ((_rootRef$value = rootRef.value) === null || _rootRef$value === void 0 ? void 0 : _rootRef$value.offsetWidth) || 0;
      var scaledWidth = state.scale * rootOffsetWidth;
      return Math.max(0, (scaledWidth - rootOffsetWidth) / 2);
    };
    var getMaxDraggedY = function getMaxDraggedY(index2) {
      var _rootRef$value2, _imagesSize$index, _imageInfoList$value$;
      var rootOffsetHeight = ((_rootRef$value2 = rootRef.value) === null || _rootRef$value2 === void 0 ? void 0 : _rootRef$value2.offsetHeight) || 0;
      var currentImageHeight = (imagesSize === null || imagesSize === void 0 || (_imagesSize$index = imagesSize[index2]) === null || _imagesSize$index === void 0 ? void 0 : _imagesSize$index.height) || 0;
      var currentImageScaledHeight = state.scale * currentImageHeight;
      var halfScaleHeight = (currentImageScaledHeight - currentImageHeight) / 2;
      if (currentImageScaledHeight <= rootOffsetHeight) {
        return {
          top: 0,
          bottom: 0
        };
      }
      var diffHeight = currentImageScaledHeight - rootOffsetHeight;
      var centerDraggedY = diffHeight / 2;
      var alignmentDraggedY = {
        start: {
          top: -diffHeight + halfScaleHeight,
          bottom: halfScaleHeight
        },
        center: {
          top: -centerDraggedY,
          bottom: centerDraggedY
        },
        end: {
          top: -halfScaleHeight,
          bottom: diffHeight - halfScaleHeight
        }
      };
      var alignment = ((_imageInfoList$value$ = imageInfoList.value[index2]) === null || _imageInfoList$value$ === void 0 || (_imageInfoList$value$ = _imageInfoList$value$.image) === null || _imageInfoList$value$ === void 0 ? void 0 : _imageInfoList$value$.align) || "center";
      return alignmentDraggedY[alignment];
    };
    var setScale = function setScale(scale) {
      scale = Math.min(scale, +props2.maxZoom + 1);
      if (scale !== state.scale) {
        state.scale = scale;
        if (scale === 1) {
          state.draggedX = 0;
          state.draggedY = 0;
        }
      }
    };
    var dragStartTime;
    var dblTapTimer;
    var toggleScale = function toggleScale() {
      var scale = state.scale > 1 ? 1 : 2;
      setScale(scale);
    };
    var onTransitionEnd = function onTransitionEnd(index2) {
      if (index2 === state.touchIndex) {
        state.dblTapZooming = false;
        clearTimeout(dblTapTimer);
        dblTapTimer = null;
      }
    };
    var onTransitionStart = function onTransitionStart(index2) {
      if (index2 === state.touchIndex) {
        state.dblTapZooming = true;
        clearTimeout(dblTapTimer);
      }
    };
    var checkTap = function checkTap(e) {
      var event = e.event;
      var deltaTime = Date.now() - dragStartTime;
      if (deltaTime < TAP_TIME && isBrowser) {
        if (dblTapTimer) {
          clearTimeout(dblTapTimer);
          dblTapTimer = window.setTimeout(function () {
            clearTimeout(dblTapTimer);
            state.dragging = false;
            toggleScale();
          }, TAP_TIME);
        } else {
          dblTapTimer = window.setTimeout(function () {
            handleClose(event, "overlay");
            dblTapTimer = null;
          }, TAP_TIME);
        }
      }
    };
    var onPinchChange = function onPinchChange(scale, index2) {
      state.zooming = true;
      state.touchIndex = index2;
      setScale(scale);
    };
    var onPinchEnd = function onPinchEnd() {
      state.zooming = false;
      if (state.scale < 1) {
        setScale(1);
      }
      if (state.scale > props2.maxZoom) {
        state.scale = +props2.maxZoom;
      }
    };
    var handlePinch = function handlePinch(pinState, index2) {
      var last = pinState.last,
        _pinState$offset = _slicedToArray(pinState.offset, 1),
        d = _pinState$offset[0];
      if (!(imagesSize !== null && imagesSize !== void 0 && imagesSize[index2])) return;
      if (state.dblTapZooming) return;
      if (!last) {
        onPinchChange(d, index2);
      } else {
        onPinchEnd();
      }
    };
    var handleDrag = function handleDrag(dragState, index2) {
      state.touchIndex = index2;
      var _ref2 = swiperRootRef.value || {},
        setOffset = _ref2.setOffset;
      if (!(imagesSize !== null && imagesSize !== void 0 && imagesSize[index2])) return;
      var first = dragState.first,
        movement = dragState.movement,
        _movement = dragState._movement,
        elapsedTime = dragState.elapsedTime,
        tap = dragState.tap,
        offset = dragState.offset,
        overflow = dragState.overflow,
        _delta = dragState._delta;
      if (first) {
        dragStartTime = Date.now();
      }
      if (tap && elapsedTime > 0 && elapsedTime < 300) {
        checkTap(dragState);
        return;
      }
      if (state.dblTapZooming) {
        dragState === null || dragState === void 0 || dragState.cancel();
        return;
      }
      state.dragging = true;
      state.draggedY = (offset === null || offset === void 0 ? void 0 : offset[1]) || 0;
      if (state.scale === 1) return;
      state.draggedX = (offset === null || offset === void 0 ? void 0 : offset[0]) || 0;
      if (movement[0] !== _movement[0] && overflow[0] !== 0) {
        state.extraDraggedX += _delta[0] / 5;
        setOffset === null || setOffset === void 0 || setOffset(state.extraDraggedX, "X");
      } else if (state.extraDraggedX !== 0) {
        state.extraDraggedX = 0;
        setOffset === null || setOffset === void 0 || setOffset(state.extraDraggedX, "X");
      }
    };
    var handleDragEnd = function handleDragEnd(dragState) {
      var overflow = dragState.overflow,
        last = dragState.last;
      var _ref3 = swiperRootRef.value || {},
        goPrev = _ref3.goPrev,
        goNext = _ref3.goNext,
        swiperContainer = _ref3.swiperContainer;
      state.dragging = false;
      if (state.extraDraggedX !== 0 && last) {
        if (Math.abs(state.extraDraggedX) > 50) {
          state.extraDraggedX = 0;
          overflow[0] < 0 ? goNext === null || goNext === void 0 ? void 0 : goNext("touch") : goPrev === null || goPrev === void 0 ? void 0 : goPrev("touch");
          return;
        }
        state.extraDraggedX = 0;
        nextTick(function () {
          var _swiperContainer$styl, _swiperContainer$styl2, _swiperContainer$styl3, _swiperContainer$styl4;
          swiperContainer === null || swiperContainer === void 0 || (_swiperContainer$styl = swiperContainer.style) === null || _swiperContainer$styl === void 0 || (_swiperContainer$styl2 = _swiperContainer$styl.setProperty) === null || _swiperContainer$styl2 === void 0 || _swiperContainer$styl2.call(_swiperContainer$styl, "transform", "translateX(0)");
          swiperContainer === null || swiperContainer === void 0 || (_swiperContainer$styl3 = swiperContainer.style) === null || _swiperContainer$styl3 === void 0 || (_swiperContainer$styl4 = _swiperContainer$styl3.setProperty) === null || _swiperContainer$styl4 === void 0 || _swiperContainer$styl4.call(_swiperContainer$styl3, "transition", "transform 0.3s");
        });
      }
    };
    var gestureOptions = reactive({
      destroyInvisible: true,
      visible: !!visibleValue.value
    });
    gestureRef.value = useGesture(gestureOptions);
    watch(function () {
      return visibleValue.value;
    }, function (newVal) {
      return gestureOptions.visible = !!newVal;
    });
    watch(function () {
      return [visibleValue.value, swiperItemRefs.value];
    }, function (_ref4) {
      var _ref5 = _slicedToArray(_ref4, 2),
        newVisible = _ref5[0],
        newRefs = _ref5[1];
      if (!newVisible) return;
      nextTick(function () {
        var _newRefs$forEach;
        (_newRefs$forEach = newRefs.forEach) === null || _newRefs$forEach === void 0 || _newRefs$forEach.call(newRefs, function (item, index2) {
          var _gestureRef$value;
          var $el = item.$el;
          (_gestureRef$value = gestureRef.value) === null || _gestureRef$value === void 0 || _gestureRef$value.create($el, {
            onDrag: function onDrag(dragState) {
              return handleDrag(dragState, index2);
            },
            onDragEnd: function onDragEnd(dragState) {
              return handleDragEnd(dragState);
            },
            onPinch: function onPinch(pinchState) {
              return handlePinch(pinchState, index2);
            }
          }, {
            drag: {
              from: function from() {
                return [state.draggedX, state.draggedY];
              },
              pointer: {
                touch: true
              },
              bounds: function bounds() {
                return {
                  top: getMaxDraggedY(index2).top,
                  right: getMaxDraggedX(),
                  bottom: getMaxDraggedY(index2).bottom,
                  left: -getMaxDraggedX()
                };
              }
            },
            pinch: {
              from: function from() {
                return [state.scale, 0];
              },
              pointer: {
                touch: true
              }
            }
          });
        });
      });
    });
    watch(function () {
      return state.scale;
    }, function (newVal) {
      return disabled.value = newVal !== 1;
    });
    onUnmounted(function () {
      clearTimeout(dblTapTimer);
    });
    return function () {
      var _currentIndex$value2, _props2$images, _props2$images2;
      var _slot;
      return createVNode(Transition, {
        "name": "fade"
      }, {
        default: function _default() {
          return [visibleValue.value && createVNode("div", {
            "ref": rootRef,
            "class": "".concat(imageViewerClass.value)
          }, [createVNode("div", {
            "class": "".concat(imageViewerClass.value, "__mask"),
            "onClick": function onClick(e) {
              return handleClose(e, "overlay");
            }
          }, null), createVNode(Swiper, {
            "ref": swiperRootRef,
            "autoplay": false,
            "class": "".concat(imageViewerClass.value, "__content"),
            "height": "100vh",
            "defaultCurrent": currentIndex.value,
            "disabled": disabled.value,
            "onChange": onSwiperChange
          }, _isSlot(_slot = imageInfoList.value.map(function (info, index2) {
            return createVNode(SwiperItem, {
              "ref": function ref(item) {
                return swiperItemRefs.value[index2] = item;
              },
              "key": index2,
              "class": "".concat(imageViewerClass.value, "__swiper-item"),
              "style": "touch-action: none; align-items:".concat(info.image.align, ";")
            }, {
              default: function _default() {
                return [info.preload ? createVNode("img", {
                  "src": info.image.url,
                  "style": "\n                      transform: ".concat(index2 === state.touchIndex ? imageTransform.value : "matrix(1, 0, 0, 1, 0, 0)", ";\n                      ").concat(imageTransitionDuration.value, ";"),
                  "class": "".concat(imageViewerClass.value, "__img"),
                  "onLoad": function onLoad(event) {
                    return onImgLoad(event, index2);
                  },
                  "onTransitionstart": function onTransitionstart(event) {
                    if (event.target === event.currentTarget) {
                      onTransitionStart(index2);
                    }
                  },
                  "onTransitionend": function onTransitionend(event) {
                    if (event.target === event.currentTarget) {
                      onTransitionEnd(index2);
                    }
                  }
                }, null) : createVNode("span", null, null)];
              }
            });
          })) ? _slot : {
            default: function _default() {
              return [_slot];
            }
          }), createVNode("div", {
            "class": "".concat(imageViewerClass.value, "__nav")
          }, [createVNode("div", {
            "class": "".concat(imageViewerClass.value, "__nav-close"),
            "onClick": function onClick(e) {
              return handleClose(e, "close-btn");
            }
          }, [closeNode.value]), props2.showIndex && createVNode("div", {
            "class": "".concat(imageViewerClass.value, "__nav-index")
          }, ["".concat(Math.min(((_currentIndex$value2 = currentIndex.value) !== null && _currentIndex$value2 !== void 0 ? _currentIndex$value2 : 0) + 1, (_props2$images = props2.images) === null || _props2$images === void 0 ? void 0 : _props2$images.length), "/").concat((_props2$images2 = props2.images) === null || _props2$images2 === void 0 ? void 0 : _props2$images2.length)]), createVNode("div", {
            "class": "".concat(imageViewerClass.value, "__nav-delete"),
            "onClick": handleDelete
          }, [deleteNode.value])])])];
        }
      });
    };
  }
});

export { _ImageViewer as default };
//# sourceMappingURL=image-viewer.js.map
