/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { defineComponent, computed, withDirectives, createVNode, resolveDirective } from 'vue';
import { ChevronRightIcon } from 'tdesign-icons-vue-next';
import config from '../config.js';
import props from './props.js';
import { useFormDisabled } from '../form/hooks.js';
import { usePrefixClass } from '../hooks/useClass.js';
import { useTNodeJSX, useContent } from '../hooks/tnode.js';
import Hover from '../shared/hover.js';
import 'lodash-es';
import '../config-provider/useConfig.js';
import '../config-provider/context.js';
import '../_common/js/global-config/mobile/default-config.js';
import '../_common/js/global-config/mobile/locale/zh_CN.js';
import '../_chunks/dep-f8b538c0.js';
import '@babel/runtime/helpers/typeof';
import '../_chunks/dep-53f63811.js';
import 'dayjs';
import '../hooks/render-tnode.js';

var prefix = config.prefix;
var _Cell = defineComponent({
  name: "".concat(prefix, "-cell"),
  directives: {
    Hover: Hover
  },
  props: props,
  setup: function setup(props2) {
    var renderTNodeJSX = useTNodeJSX();
    var renderTNodeContent = useContent();
    var disabled = useFormDisabled();
    var cellClass = usePrefixClass("cell");
    var cellClasses = computed(function () {
      return ["".concat(cellClass.value), _defineProperty({}, "".concat(cellClass.value, "--borderless"), !props2.bordered)];
    });
    var hoverDisabled = computed(function () {
      return !props2.hover || disabled.value;
    });
    var handleClick = function handleClick(e) {
      if (!disabled.value) {
        var _props2$onClick;
        (_props2$onClick = props2.onClick) === null || _props2$onClick === void 0 || _props2$onClick.call(props2, {
          e: e
        });
      }
    };
    var renderImage = function renderImage() {
      if (typeof props2.image === "string") {
        return createVNode("img", {
          "src": props2.image,
          "class": "".concat(cellClass.value, "__left-image")
        }, null);
      }
      var image = renderTNodeJSX("image");
      return image;
    };
    var renderLeft = function renderLeft() {
      var leftIcon = renderTNodeJSX("leftIcon");
      return createVNode("div", {
        "class": "".concat(cellClass.value, "__left")
      }, [leftIcon && createVNode("div", {
        "class": "".concat(cellClass.value, "__left-icon")
      }, [leftIcon]), renderImage()]);
    };
    var renderTitle = function renderTitle() {
      var title = renderTNodeJSX("title");
      if (!title) {
        return null;
      }
      var description = renderTNodeJSX("description");
      return createVNode("div", {
        "class": "".concat(cellClass.value, "__title")
      }, [createVNode("div", {
        "class": "".concat(cellClass.value, "__title-text")
      }, [title, props2.required && createVNode("span", {
        "class": "".concat(cellClass.value, "--required")
      }, ["\xA0*"])]), description && createVNode("div", {
        "class": "".concat(cellClass.value, "__description")
      }, [description])]);
    };
    var renderRight = function renderRight() {
      var rightIcon = props2.arrow ? createVNode(ChevronRightIcon, null, null) : renderTNodeJSX("rightIcon");
      if (!rightIcon) {
        return null;
      }
      return createVNode("div", {
        "class": ["".concat(cellClass.value, "__right"), "".concat(cellClass.value, "__right--").concat(props2.align)]
      }, [createVNode("div", {
        "class": "".concat(cellClass.value, "__right-icon")
      }, [rightIcon])]);
    };
    return function () {
      var note = renderTNodeContent("default", "note");
      return withDirectives(createVNode("div", {
        "class": cellClasses.value,
        "onClick": handleClick
      }, [renderLeft(), renderTitle(), note && createVNode("div", {
        "class": "".concat(cellClass.value, "__note")
      }, [note]), renderRight()]), [[resolveDirective("hover"), {
        className: "".concat(cellClass.value, "--hover"),
        disabledHover: hoverDisabled.value
      }]]);
    };
  }
});

export { _Cell as default };
//# sourceMappingURL=cell.js.map
