/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { defineComponent, ref, onMounted, nextTick, onUpdated, createVNode } from 'vue';
import circleAdapter from '../../_common/js/loading/circle-adapter.js';
import config from '../../config.js';
import { usePrefixClass } from '../../hooks/useClass.js';
import '@babel/runtime/helpers/defineProperty';
import '../../_common/js/utils/setStyle.js';
import '../../_common/js/utils/helper.js';
import '@babel/runtime/helpers/toConsumableArray';
import '@babel/runtime/helpers/objectWithoutProperties';
import '@babel/runtime/helpers/slicedToArray';
import 'lodash-es';
import '../../config-provider/useConfig.js';
import '../../config-provider/context.js';
import '../../_common/js/global-config/mobile/default-config.js';
import '../../_common/js/global-config/mobile/locale/zh_CN.js';
import '../../_chunks/dep-f8b538c0.js';
import '@babel/runtime/helpers/typeof';
import '../../_chunks/dep-53f63811.js';
import 'dayjs';

var prefix = config.prefix;
var TGradientIcon = defineComponent({
  name: "".concat(prefix, "-gradient"),
  props: {
    style: Object
  },
  setup: function setup(props) {
    var gradientClass = usePrefixClass("loading__gradient");
    var classes = [gradientClass.value, "".concat(prefix, "-icon-loading")];
    var circle = ref();
    var updateColor = function updateColor() {
      var circleElem = circle.value;
      circleAdapter(circleElem);
    };
    onMounted(function () {
      nextTick(function () {
        updateColor();
      });
    });
    onUpdated(function () {
      updateColor();
    });
    return function () {
      return createVNode("svg", {
        "style": props.style,
        "class": classes,
        "viewBox": "0 0 12 12",
        "version": "1.1",
        "width": "1em",
        "height": "1em",
        "xmlns": "http://www.w3.org/2000/svg"
      }, [createVNode("foreignObject", {
        "x": "0",
        "y": "0",
        "width": "12",
        "height": "12"
      }, [createVNode("div", {
        "ref": circle,
        "class": "".concat(gradientClass.value, "-conic")
      }, null)])]);
    };
  }
});

export { TGradientIcon as default };
//# sourceMappingURL=gradient.js.map
