/**
 * tdesign v1.9.0
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { defineComponent, ref, computed, createVNode, resolveComponent, mergeProps, Fragment } from 'vue';
import { CloseIcon, LoadingIcon, CloseCircleIcon, AddIcon } from 'tdesign-icons-vue-next';
import { Image } from '../image/index.js';
import { ImageViewer } from '../image-viewer/index.js';
import UploadProps from './props.js';
import config from '../config.js';
import useUpload from './hooks/useUpload.js';
import { useTNodeJSX, useContent } from '../hooks/tnode.js';
import { usePrefixClass } from '../hooks/useClass.js';
import { useConfig } from '../config-provider/useConfig.js';
import '../image/image.js';
import '@babel/runtime/helpers/slicedToArray';
import '@babel/runtime/helpers/defineProperty';
import '@vueuse/core';
import '../loading/index.js';
import '../loading/loading.js';
import '../loading/icon/gradient.js';
import '../_common/js/loading/circle-adapter.js';
import '../_common/js/utils/setStyle.js';
import '../_common/js/utils/helper.js';
import '@babel/runtime/helpers/toConsumableArray';
import '@babel/runtime/helpers/objectWithoutProperties';
import 'lodash-es';
import '../loading/icon/spinner.js';
import '../loading/props.js';
import '../shared/dom.js';
import '../loading/plugin.js';
import '../hooks/render-tnode.js';
import '../config-provider/context.js';
import '../_common/js/global-config/mobile/default-config.js';
import '../_common/js/global-config/mobile/locale/zh_CN.js';
import '../_chunks/dep-f8b538c0.js';
import '@babel/runtime/helpers/typeof';
import '../_chunks/dep-53f63811.js';
import 'dayjs';
import '../shared/component.js';
import '../image/props.js';
import '../image-viewer/image-viewer.js';
import '../image-viewer/props.js';
import '../hooks/useDefaultValue.js';
import '../hooks/useVModel.js';
import '../swiper/index.js';
import '../swiper/swiper.js';
import '../swipe-cell/useSwipe.js';
import '../shared/util.js';
import '../swiper/props.js';
import '../swiper/swiper-item.js';
import '../shared/useGesture/index.js';
import '@use-gesture/vanilla';
import '../_common/js/upload/main.js';
import '@babel/runtime/helpers/toArray';
import '../_common/js/upload/utils.js';
import '../_common/js/log/log.js';
import '../_common/js/upload/xhr.js';

var prefix = config.prefix;
var _Upload = defineComponent({
  name: "".concat(prefix, "-upload"),
  components: {
    TImage: Image
  },
  props: UploadProps,
  emits: ["update:files", "update:modelValue", "change", "fail", "preview", "progress", "remove", "success", "select-change", "validate", "click-upload"],
  setup: function setup(props, _ref) {
    var expose = _ref.expose;
    var uploadClass = usePrefixClass("upload");
    var _useConfig = useConfig("upload"),
      globalConfig = _useConfig.globalConfig;
    var _useUpload = useUpload(props),
      disabled = _useUpload.disabled,
      displayFiles = _useUpload.displayFiles,
      uploading = _useUpload.uploading,
      inputRef = _useUpload.inputRef,
      uploadFilePercent = _useUpload.uploadFilePercent,
      uploadFiles = _useUpload.uploadFiles,
      onNormalFileChange = _useUpload.onNormalFileChange,
      onInnerRemove = _useUpload.onInnerRemove,
      cancelUpload = _useUpload.cancelUpload;
    var renderTNodeJSX = useTNodeJSX();
    var renderContent = useContent();
    var showViewer = ref(false);
    var initialIndex = ref(0);
    var handlePreview = function handlePreview(e, file, index) {
      var _props$onPreview;
      initialIndex.value = index;
      showViewer.value = props.preview;
      (_props$onPreview = props.onPreview) === null || _props$onPreview === void 0 || _props$onPreview.call(props, {
        e: e,
        file: file,
        index: index
      });
    };
    var triggerUpload = function triggerUpload(e) {
      var _props$onClickUpload;
      var input = inputRef.value;
      if (disabled !== null && disabled !== void 0 && disabled.value) return;
      input.click();
      (_props$onClickUpload = props.onClickUpload) === null || _props$onClickUpload === void 0 || _props$onClickUpload.call(props, {
        e: e
      });
    };
    var previewImgs = computed(function () {
      return displayFiles.value.map(function (item) {
        return item.url;
      });
    });
    var handleImageClose = function handleImageClose(_ref2) {
      var visible = _ref2.visible;
      showViewer.value = visible;
    };
    var renderStatus = function renderStatus(file) {
      if (file.status === "fail" || file.status === "progress") {
        return createVNode("div", {
          "class": "".concat(uploadClass.value, "__progress-mask")
        }, [file.status === "progress" ? createVNode(Fragment, null, [createVNode(LoadingIcon, {
          "class": "".concat(uploadClass.value, "__progress-loading"),
          "size": "24"
        }, null), createVNode("div", {
          "class": "".concat(uploadClass.value, "__progress-text")
        }, [file.percent ? "".concat(file.percent, "%") : globalConfig.value.progress.uploadingText])]) : createVNode(CloseCircleIcon, {
          "size": "24"
        }, null), file.status === "fail" && createVNode("div", {
          "class": "".concat(uploadClass.value, "__progress-text")
        }, [globalConfig.value.progress.failText])]);
      }
    };
    var content = function content() {
      var _displayFiles$value;
      var defaultContent = renderContent("default", "content");
      var addContent = renderTNodeJSX("addContent");
      if (props.max === 0 || props.max > 0 && ((_displayFiles$value = displayFiles.value) === null || _displayFiles$value === void 0 ? void 0 : _displayFiles$value.length) < props.max) {
        if (defaultContent) {
          return createVNode("div", {
            "onClick": triggerUpload
          }, [defaultContent]);
        }
        return createVNode("div", {
          "class": "".concat(uploadClass.value, "__item ").concat(uploadClass.value, "__item--add"),
          "onClick": triggerUpload
        }, [createVNode("div", {
          "class": "".concat(uploadClass.value, "__add-icon")
        }, [addContent || createVNode(AddIcon, {
          "size": "28"
        }, null)])]);
      }
    };
    expose({
      upload: inputRef.value,
      uploading: uploading,
      triggerUpload: triggerUpload,
      uploadFiles: uploadFiles,
      cancelUpload: cancelUpload,
      uploadFilePercent: uploadFilePercent
    });
    return function () {
      return createVNode("div", {
        "class": "".concat(uploadClass.value)
      }, [displayFiles.value.map(function (file, index) {
        return createVNode("div", {
          "key": index,
          "class": "".concat(uploadClass.value, "__item")
        }, [file.url && createVNode(resolveComponent("t-image"), mergeProps({
          "class": "".concat(uploadClass.value, "__image"),
          "shape": "round"
        }, props.imageProps, {
          "src": file.url,
          "onClick": function onClick(e) {
            return handlePreview(e, file, index);
          }
        }), null), renderStatus(file), createVNode(CloseIcon, {
          "class": "".concat(uploadClass.value, "__delete-btn"),
          "onClick": function onClick(_ref3) {
            var e = _ref3.e;
            return onInnerRemove({
              e: e,
              file: file,
              index: index
            });
          }
        }, null)]);
      }), content(), createVNode("input", {
        "ref": inputRef,
        "value": props.files,
        "type": "file",
        "multiple": props.multiple,
        "hidden": true,
        "capture": props.capture,
        "accept": props.accept,
        "onChange": onNormalFileChange
      }, null), createVNode(ImageViewer, {
        "visible": showViewer.value,
        "images": previewImgs.value,
        "index": initialIndex.value,
        "onClose": handleImageClose
      }, null)]);
    };
  }
});

export { _Upload as default };
//# sourceMappingURL=upload.js.map
